@@ -13,7 +13,6 @@
 import datetime
 
 from oslo_utils import timeutils
-from oslo_utils import uuidutils
 
 from novaclient.tests.functional import base
 
@@ -25,12 +24,17 @@ class TestServersBootNovaClient(base.ClientTestBase):
 
     def _boot_server_with_legacy_bdm(self, bdm_params=()):
         volume_size = 1
-        volume_name = uuidutils.generate_uuid()
+        volume_name = self.name_generate()
         volume = self.cinder.volumes.create(size=volume_size,
                                             name=volume_name,
                                             imageRef=self.image.id)
         self.wait_for_volume_status(volume, "available")
 
+        if (len(bdm_params) >= 3 and bdm_params[2] == '1'):
+            delete_volume = False
+        else:
+            delete_volume = True
+
         bdm_params = ':'.join(bdm_params)
         if bdm_params:
             bdm_params = ''.join((':', bdm_params))
@@ -38,7 +42,7 @@ class TestServersBootNovaClient(base.ClientTestBase):
         params = (
             "%(name)s --flavor %(flavor)s --poll "
             "--block-device-mapping vda=%(volume_id)s%(bdm_params)s" % {
-                "name": uuidutils.generate_uuid(), "flavor":
+                "name": self.name_generate(), "flavor":
                     self.flavor.id,
                 "volume_id": volume.id,
                 "bdm_params": bdm_params})
@@ -51,9 +55,13 @@ class TestServersBootNovaClient(base.ClientTestBase):
         self.client.servers.delete(server_id)
         self.wait_for_resource_delete(server_id, self.client.servers)
 
+        if delete_volume:
+            self.cinder.volumes.delete(volume.id)
+            self.wait_for_resource_delete(volume.id, self.cinder.volumes)
+
     def test_boot_server_with_legacy_bdm(self):
         # bdm v1 format
-        # <id>:<type>:<size(GB)>:<delete-on-terminate>
+        # <id>:<type>:<size(GiB)>:<delete-on-terminate>
         # params = (type, size, delete-on-terminate)
         params = ('', '', '1')
         self._boot_server_with_legacy_bdm(bdm_params=params)
@@ -64,15 +72,56 @@ class TestServersBootNovaClient(base.ClientTestBase):
     def test_boot_server_with_net_name(self):
         server_info = self.nova("boot", params=(
             "%(name)s --flavor %(flavor)s --image %(image)s --poll "
-            "--nic net-name=%(net-name)s" % {"name": uuidutils.generate_uuid(),
+            "--nic net-name=%(net-name)s" % {"name": self.name_generate(),
                                              "image": self.image.id,
                                              "flavor": self.flavor.id,
-                                             "net-name": self.network.label}))
+                                             "net-name": self.network.name}))
         server_id = self._get_value_from_the_table(server_info, "id")
 
         self.client.servers.delete(server_id)
         self.wait_for_resource_delete(server_id, self.client.servers)
 
+    def test_boot_server_using_image_with(self):
+        """Scenario test which does the following:
+
+        1. Create a server.
+        2. Create a snapshot image of the server with a special meta key.
+        3. Create a second server using the --image-with option using the meta
+           key stored in the snapshot image created in step 2.
+        """
+        # create the first server and wait for it to be active
+        server_info = self.nova('boot', params=(
+            '--flavor %(flavor)s --image %(image)s --poll '
+            'image-with-server-1' % {'image': self.image.id,
+                                     'flavor': self.flavor.id}))
+        server_id = self._get_value_from_the_table(server_info, 'id')
+        self.addCleanup(self._cleanup_server, server_id)
+
+        # create a snapshot of the server with an image metadata key
+        snapshot_info = self.nova('image-create', params=(
+            '--metadata image_with_meta=%(meta_value)s '
+            '--show --poll %(server_id)s image-with-snapshot' % {
+                'meta_value': server_id,
+                'server_id': server_id}))
+
+        # get the snapshot image id out of the output table for the second
+        # server create request
+        snapshot_id = self._get_value_from_the_table(snapshot_info, 'id')
+        self.addCleanup(self.glance.images.delete, snapshot_id)
+
+        # verify the metadata was set on the snapshot image
+        meta_value = self._get_value_from_the_table(
+            snapshot_info, 'image_with_meta')
+        self.assertEqual(server_id, meta_value)
+
+        # create the second server using --image-with
+        server_info = self.nova('boot', params=(
+            '--flavor %(flavor)s --image-with image_with_meta=%(meta_value)s '
+            '--poll image-with-server-2' % {'meta_value': server_id,
+                                            'flavor': self.flavor.id}))
+        server_id = self._get_value_from_the_table(server_info, 'id')
+        self.addCleanup(self._cleanup_server, server_id)
+
 
 class TestServersListNovaClient(base.ClientTestBase):
     """Servers list functional tests."""
@@ -83,7 +132,7 @@ class TestServersListNovaClient(base.ClientTestBase):
         return [self._create_server(name) for i in range(number)]
 
     def test_list_with_limit(self):
-        name = uuidutils.generate_uuid()
+        name = self.name_generate()
         self._create_servers(name, 2)
         output = self.nova("list", params="--limit 1 --name %s" % name)
         # Cut header and footer of the table
@@ -92,7 +141,7 @@ class TestServersListNovaClient(base.ClientTestBase):
 
     def test_list_with_changes_since(self):
         now = datetime.datetime.isoformat(timeutils.utcnow())
-        name = uuidutils.generate_uuid()
+        name = self.name_generate()
         self._create_servers(name, 1)
         output = self.nova("list", params="--changes-since %s" % now)
         self.assertIn(name, output, output)
@@ -101,7 +150,7 @@ class TestServersListNovaClient(base.ClientTestBase):
         self.assertNotIn(name, output, output)
 
     def test_list_all_servers(self):
-        name = uuidutils.generate_uuid()
+        name = self.name_generate()
         precreated_servers = self._create_servers(name, 3)
         # there are no possibility to exceed the limit on API side, so just
         # check that "-1" limit processes by novaclient side
@@ -109,3 +158,14 @@ class TestServersListNovaClient(base.ClientTestBase):
         # Cut header and footer of the table
         for server in precreated_servers:
             self.assertIn(server.id, output)
+
+    def test_list_minimal(self):
+        server = self._create_server()
+        server_output = self.nova("list --minimal")
+        # The only fields output are "ID" and "Name"
+        output_uuid = self._get_column_value_from_single_row_table(
+            server_output, 'ID')
+        output_name = self._get_column_value_from_single_row_table(
+            server_output, 'Name')
+        self.assertEqual(output_uuid, server.id)
+        self.assertEqual(output_name, server.name)
